package com.vendor.platform.ui.internal;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.vendor.platform.api.IDeviceManager;
import com.vendor.platform.core.IToolManager;
import com.vendor.platform.core.PlatformCoreActivator;
import com.vendor.platform.core.ToolDescriptor;
import com.vendor.platform.core.internal.DeviceManager;
import com.vendor.platform.ui.internal.BundleUtils;
import com.vendor.platform.ui.internal.PerspectiveUtil;
import com.vendor.platform.ui.internal.RegisterUtils;
import com.vendor.platform.ui.internal.StringConstants;
import java.util.List;
import org.eclipse.core.runtime.Plugin;
import org.eclipse.equinox.p2.metadata.IInstallableUnit;
import org.eclipse.swt.widgets.Display;
import org.osgi.service.prefs.Preferences;

public class ToolStateControlUtils {
  private static String TRUE = StringConstants.decode("1953658213");
  
  private static String TOOL_STATE_NODE = StringConstants.decode("549850129448369708430437");
  
  private static final String TOOL_STATE_AUTO_MODIFY_FOR_CHIP_NODE = "tool.auto";
  
  private static final String TOOL_STATE_HAND_MODIFY_NODE = "tool.hand";
  
  public static void setToolPlatformRelativeState(String toolID, boolean state) {
    Preferences node = getPlatformRelativeToolStatePreferences();
    try {
      if (node != null) {
        node.put(computeToolKeyForPlatformStateChange(toolID), 
            String.valueOf(state));
        node.flush();
      } 
    } catch (Exception e) {
      PlatformCoreActivator.getLogger((Plugin)PlatformCoreActivator.getDefault())
        .logError(e.getMessage(), e);
    } 
  }
  
  public static void setToolAuthorityState(String toolID, boolean state) {
    Preferences node = getPlatformRelativeToolStatePreferences();
    try {
      if (node != null) {
        node.put(computeToolKeyForAuthority(toolID), 
            String.valueOf(state));
        node.flush();
      } 
    } catch (Exception e) {
      PlatformCoreActivator.getLogger((Plugin)PlatformCoreActivator.getDefault())
        .logError(e.getMessage(), e);
    } 
  }
  
  public static boolean isToolAutoEnabledByPlatform(String toolID) {
    Preferences node = getPlatformRelativeToolStatePreferences();
    try {
      if (node != null) {
        String state = node.get(
            computeToolKeyForPlatformStateChange(toolID), TRUE);
        return Boolean.valueOf(state).booleanValue();
      } 
    } catch (Exception e) {
      PlatformCoreActivator.getLogger((Plugin)PlatformCoreActivator.getDefault())
        .logError(e.getMessage(), e);
    } 
    return true;
  }
  
  public static boolean isToolAutoEnabledByAhthority(String toolID) {
    Preferences node = getPlatformRelativeToolStatePreferences();
    try {
      if (node != null) {
        String state = node.get(computeToolKeyForAuthority(toolID), TRUE);
        return Boolean.valueOf(state).booleanValue();
      } 
    } catch (Exception e) {
      PlatformCoreActivator.getLogger((Plugin)PlatformCoreActivator.getDefault())
        .logError(e.getMessage(), e);
    } 
    return true;
  }
  
  private static Preferences getPlatformRelativeToolStatePreferences() {
    return PlatformCoreActivator.getDefault().getPreferenceNode("com.vendor.platform.core", TOOL_STATE_NODE);
  }
  
  public static void autoEnableToolsForPlatform() {
    IToolManager m = PlatformCoreActivator.getDefault().getToolManager();
    List<IInstallableUnit> installIUs = m.getInstalledToolAndPlatformIUs();
    List<ToolDescriptor> installTools = m.collectFeatureToolsAndPlatform(installIUs);
    if (installTools != null && installTools.size() > 0) {
      IDeviceManager deviceManager = DeviceManager.getInstance();
      for (int i = 0; i < installTools.size(); i++) {
        ToolDescriptor tool = installTools.get(i);
        if (!BundleUtils.isToolEnabled(tool) && 
          !isToolAutoEnabledByPlatform(tool.getId())) {
          setToolPlatformRelativeState(tool
              .getId(), true);
          autoEnableTools(deviceManager.getCurrentDevice(), tool);
        } 
      } 
    } 
  }
  
  public static void autoEnableToolForAuthority(ToolDescriptor input) {
    IToolManager m = PlatformCoreActivator.getDefault().getToolManager();
    List<IInstallableUnit> installIUs = m.getInstalledToolAndPlatformIUs();
    List<ToolDescriptor> installTools = m.collectFeatureToolsAndPlatform(installIUs);
    if (installTools != null && installTools.size() > 0) {
      IDeviceManager deviceManager = DeviceManager.getInstance();
      for (int i = 0; i < installTools.size(); i++) {
        ToolDescriptor tool = installTools.get(i);
        String name = (String)tool.getProperties().get("tool.name");
        String inputName = (String)input.getProperties().get("tool.name");
        if (name != null && inputName != null && name.equals(inputName)) {
          if (!BundleUtils.isToolEnabled(tool) && 
            !isToolAutoEnabledByAhthority(tool.getId())) {
            setToolAuthorityState(tool
                .getId(), true);
            autoEnableTools(deviceManager.getCurrentDevice(), tool);
          } 
          break;
        } 
      } 
    } 
  }
  
  public static void autoPlatformDisabledTools() {
    IToolManager m = PlatformCoreActivator.getDefault().getToolManager();
    List<IInstallableUnit> installIUs = m.getInstalledToolIUs();
    List<ToolDescriptor> installTools = m.collectFeatureTools(installIUs);
    if (installTools != null && installTools.size() > 0)
      for (int i = 0; i < installTools.size(); i++) {
        ToolDescriptor tool = installTools.get(i);
        if (BundleUtils.isToolEnabled(tool))
          Display.getDefault().syncExec((Runnable)new Object(tool)); 
      }  
  }
  
  public static void autoEnableTools(String device, ToolDescriptor tool) {
    if (device == null || tool == null)
      return; 
    if (!isToolAutoEnabledByPlatform(tool.getId()))
      return; 
    if (!isToolAutoEnabledByAhthority(tool.getId()))
      return; 
    if (!BundleUtils.suitableForChip(tool, device))
      return; 
    autoEnableToolsDetail(tool);
  }
  
  public static void updateToolStateForChipChange(String device, ToolDescriptor tool, boolean b) {
    if (device == null || tool == null)
      return; 
    if (!isToolAutoEnabledByPlatform(tool.getId()))
      return; 
    if (!isToolAutoEnabledByAhthority(tool.getId()))
      return; 
    updateToolStateForChipChangeDetail(tool, true);
  }
  
  public static void autoAuthorityDisabledTool(String toolName) {
    IToolManager m = PlatformCoreActivator.getDefault().getToolManager();
    List<IInstallableUnit> installIUs = m.getInstalledToolIUs();
    List<ToolDescriptor> installTools = m.collectFeatureTools(installIUs);
    if (installTools != null && installTools.size() > 0)
      for (int i = 0; i < installTools.size(); i++) {
        ToolDescriptor tool = installTools.get(i);
        String name = (String)tool.getProperties().get("tool.name");
        if (name != null && name.equals(toolName)) {
          if (BundleUtils.isToolEnabled(tool))
            Display.getDefault().syncExec((Runnable)new Object(tool)); 
          break;
        } 
      }  
  }
  
  public static void reDisableToolsForBundleStateRestore(ToolDescriptor tool) {
    if (tool == null)
      return; 
    boolean originalEnabled = BundleUtils.isToolEnabled(tool);
    if (!originalEnabled)
      return; 
    boolean toolHandState = true;
    String toolHandStatePreferences = getToolHandStatePreferences(tool);
    if (toolHandStatePreferences.length() > 0)
      toolHandState = Boolean.valueOf(toolHandStatePreferences).booleanValue(); 
    boolean needDisableTool = (!toolHandState || !isToolAutoEnabledByPlatform(tool.getId()) || !isToolAutoEnabledByAhthority(tool.getId()));
    if (needDisableTool) {
      List list = tool.getPlugins();
      if (list.size() == 0)
        return; 
      for (Object o : list) {
        ToolDescriptor.PluginDetail p = (ToolDescriptor.PluginDetail)o;
        BundleUtils.setBundleEnabled(p.getPluginId(), false);
      } 
    } 
  }
  
  public static String computeToolKeyForPlatformStateChange(String toolID) {
    return toolID + "_platform_state";
  }
  
  public static String computeToolKeyForAuthority(String toolID) {
    return toolID + "_authority";
  }
  
  public static String getToolStatePreferences(ToolDescriptor tool) {
    Preferences node = PlatformCoreActivator.getDefault().getPreferenceNode("com.vendor.platform.core", "tool.auto");
    return node.get(tool.getId(), "");
  }
  
  public static void setAutoModifyToolState(ToolDescriptor tool, Boolean state) {
    Preferences node = PlatformCoreActivator.getDefault().getPreferenceNode("com.vendor.platform.core", "tool.auto");
    if (state == null) {
      node.remove(tool.getId());
    } else if (state.booleanValue()) {
      node.remove(tool.getId());
    } else {
      node.put(tool.getId(), String.valueOf(state));
    } 
    try {
      node.flush();
    } catch (Exception e) {
      PlatformCoreActivator.getLogger((Plugin)PlatformCoreActivator.getDefault())
        .logError(e.getMessage(), e);
    } 
  }
  
  public static String getToolHandStatePreferences(ToolDescriptor tool) {
    Preferences node = PlatformCoreActivator.getDefault().getPreferenceNode("com.vendor.platform.core", "tool.hand");
    return node.get(tool.getId(), "");
  }
  
  public static void setHandModifyToolState(ToolDescriptor tool, Boolean state) {
    Preferences node = PlatformCoreActivator.getDefault().getPreferenceNode("com.vendor.platform.core", "tool.hand");
    if (state == null) {
      node.remove(tool.getId());
    } else if (state.booleanValue()) {
      node.remove(tool.getId());
    } else {
      node.put(tool.getId(), String.valueOf(state));
    } 
    try {
      node.flush();
    } catch (Exception e) {
      PlatformCoreActivator.getLogger((Plugin)PlatformCoreActivator.getDefault())
        .logError(e.getMessage(), e);
    } 
  }
  
  public static void updateToolStateForChipChangeDetail(ToolDescriptor tool, boolean enabled) {
    if (tool == null)
      return; 
    List list = tool.getPlugins();
    if (list.size() == 0)
      return; 
    boolean originalEnabled = BundleUtils.isToolEnabled(tool);
    if (enabled == originalEnabled) {
      if (!originalEnabled)
        setAutoModifyToolState(tool, Boolean.valueOf(enabled)); 
      return;
    } 
    if (!originalEnabled) {
      if (RegisterUtils.isExpire(tool.getProperties()))
        return; 
      String toolHandStatePreferences = getToolHandStatePreferences(tool);
      if (toolHandStatePreferences.length() > 0) {
        Boolean b = Boolean.valueOf(toolHandStatePreferences);
        if (!b.booleanValue()) {
          setAutoModifyToolState(tool, Boolean.valueOf(enabled));
          return;
        } 
      } 
    } 
    if (enabled) {
      String toolStatePreferences = getToolStatePreferences(tool);
      if (toolStatePreferences.length() == 0)
        return; 
    } else {
      try {
        BundleUtils.closeToolPerspective(tool);
      } catch (Exception exception) {}
      try {
        PerspectiveUtil.removePerspectiveShortcut(tool);
      } catch (Exception exception) {}
    } 
    setAutoModifyToolState(tool, Boolean.valueOf(enabled));
    for (Object o : list) {
      ToolDescriptor.PluginDetail p = (ToolDescriptor.PluginDetail)o;
      BundleUtils.setBundleEnabled(p.getPluginId(), enabled);
    } 
  }
  
  public static void autoEnableToolsDetail(ToolDescriptor tool) {
    if (tool == null)
      return; 
    List list = tool.getPlugins();
    if (list.size() == 0)
      return; 
    boolean originalEnabled = BundleUtils.isToolEnabled(tool);
    if (originalEnabled)
      return; 
    if (!originalEnabled) {
      if (RegisterUtils.isExpire(tool.getProperties()))
        return; 
      String toolHandStatePreferences = getToolHandStatePreferences(tool);
      if (toolHandStatePreferences.length() > 0) {
        Boolean b = Boolean.valueOf(toolHandStatePreferences);
        if (!b.booleanValue())
          return; 
      } 
    } 
    for (Object o : list) {
      ToolDescriptor.PluginDetail p = (ToolDescriptor.PluginDetail)o;
      BundleUtils.setBundleEnabled(p.getPluginId(), true);
    } 
  }
}
